@@ -14,7 +14,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  * License for more details.
  *
- * RCSID $Id: ipsec_kversion.h,v 1.15.2.17 2007-10-31 19:57:40 paul Exp $
+ * RCSID $Id: ipsec_kversion.h,v 1.15.2.20 2007-11-16 06:16:10 paul Exp $
  */
 #define	_OPENSWAN_KVERSIONS_H	/* seen it, no need to see it again */
 
@@ -80,8 +80,14 @@
 #define IP_SELECT_IDENT
 #endif
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(2,3,50)) && defined(CONFIG_NETFILTER)
-#define SKB_RESET_NFCT
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,3,50)
+# if(LINUX_VERSION_CODE < KERNEL_VERSION(2,6,23) && defined(CONFIG_NETFILTER))
+#  define SKB_RESET_NFCT
+# elif LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,23)
+#  if defined(CONFIG_NF_CONNTRACK) || defined(CONFIG_NF_CONNTRACK_MODULE)
+#   define SKB_RESET_NFCT
+#  endif
+# endif
 #endif
 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,2)
@@ -142,6 +148,13 @@
 #define HAVE_NEW_SKB_LINEARIZE
 #endif
 
+/* this is the best we can do to detect XEN, which makes
+ *  * patches to linux/skbuff.h, making it look like 2.6.18 version 
+ *   */
+#ifdef CONFIG_XEN
+#define HAVE_NEW_SKB_LINEARIZE
+#endif
+
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,19)
 #define VOID_SOCK_UNREGISTER
 #endif
@@ -280,6 +293,18 @@
 
 /*
  * $Log: ipsec_kversion.h,v $
+ * Revision 1.15.2.20  2007-11-16 06:16:10  paul
+ * Fix brackets on SKB_RESET_NFCT case
+ *
+ * Revision 1.15.2.19  2007-11-16 06:01:27  paul
+ * On 2.6.23+, sk->nfct is part of skbut only when CONFIG_NF_CONNTRACK or
+ * CONFIG_NF_CONNTRACK_MODUE is set, where previously this was handled with
+ * CONFIG_NETFILTER.
+ *
+ * Revision 1.15.2.18  2007-11-07 14:17:56  paul
+ * Xen modifies skb structures, so xen kernels < 2.6.18 need to have
+ * HAVE_NEW_SKB_LINEARIZE defined.
+ *
  * Revision 1.15.2.17  2007-10-31 19:57:40  paul
  * type of sock.sk_stamp changed from timeval to ktime [dhr]
  *
